summaryrefslogtreecommitdiff
path: root/src/termhooks.h
diff options
context:
space:
mode:
authorPaul Eggert <eggert@cs.ucla.edu>2011-12-11 21:32:49 -0800
committerPaul Eggert <eggert@cs.ucla.edu>2011-12-11 21:32:49 -0800
commit333f9019e29e9b6de3a7ec07448be1d364ba540b (patch)
treefd19625604abbd2784e9c9de92c613ff965ea11d /src/termhooks.h
parent11636b221d2897aed5ca9a762d7b61afd20b6168 (diff)
Spelling fixes.
Diffstat (limited to 'src/termhooks.h')
-rw-r--r--src/termhooks.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/termhooks.h b/src/termhooks.h
index 63d166b641..5bd081d6d8 100644
--- a/src/termhooks.h
+++ b/src/termhooks.h
@@ -553,7 +553,7 @@ struct terminal
/* Arrange for all scroll bars on FRAME to be removed at the next call
to `*judge_scroll_bars_hook'. A scroll bar may be spared if
- `*redeem_scroll_bar_hook' is applied to its window before the judgement.
+ `*redeem_scroll_bar_hook' is applied to its window before the judgment.
This should be applied to each frame each time its window tree is
redisplayed, even if it is not displaying scroll bars at the moment;
@@ -565,7 +565,7 @@ struct terminal
currently displaying them. */
void (*condemn_scroll_bars_hook) (struct frame *frame);
/* Unmark WINDOW's scroll bar for deletion in this judgement cycle.
Note that it's okay to redeem a scroll bar that is not condemned. */
void (*redeem_scroll_bar_hook) (struct window *window);
@@ -565,7 +565,7 @@ struct terminal
currently displaying them. */
void (*condemn_scroll_bars_hook) (struct frame *frame);
- /* Unmark WINDOW's scroll bar for deletion in this judgement cycle.
+ /* Unmark WINDOW's scroll bar for deletion in this judgment cycle.
Note that it's okay to redeem a scroll bar that is not condemned. */
void (*redeem_scroll_bar_hook) (struct window *window);